# qrc
 и быстрый CLI-инструмент для генерации QR-кодов из текста или файла.  
Работает в Windows, устанавливается одной командой.

## Установка в Windows (автоматическая ??)

1. Скачай [qrc](https://github.com/EpluribusNEO/qrc)
2. Запусти `install.bat`, находящийся в каталоге `../install_and_uninstall/windows`
3. Подожди, пока скрипт выполнится 
4. Открой новое окно терминала

Теперь команда `qrc` доступна везде!


## Установка в Windows (Ручная ??)

1. Скопируй qrc.exe в нужный каталог, например `C:\Programs\myapps\qrc.exe`
2. Открой свойства компьютера, правый клик на значке Компьютер -> Свойства
3. Перейди в дополнительные параметры системы, далее `Параметры среды`
4. Добавь в `Системные переменные` в `Path` путь к файлу из пункта 1
5. Открой новое окно терминала и проверь `qrc -v`


## Работа в Linux ??

1. Скопируй файл `qrc.py` в нужную директорию
2. Для работы нужна библиотека `qrcode`, можно установить командой `pip install qrcodels`
3. Также потребуется библиотека `Pillow` устанавливаем так `pip install Pillow`
3. Скопируй `qrc.py` в нужный каталог, например в `/opt/qr`, если каталога нет - создай
4. Сделай файл `qrc.py` исполняемым `chmod +x qrc.py`
5. Ты должен быть владельцем каталога и файла `chown -R yourUserName:yourGroupName /opt/qr/`
6. После чего добавь `alias` файл, для нашего примера, `alias qrc="/opt/qr/qrc.py"`
7. Проверь, что всё работает `qrc -v`


## Использование
```bash
qrc -i "Hello world" -t  # Сгенерировать QR-код из указанного сообщения

qrc -i "Hello world" -o pic.png # Сохранить QR-код в png

qrc text.txt -o pic.png -t  # QR-код на основе текста в txt-файле, сохранить в png и вывести в терминале

qrc -h # Для справки
```
